@@ -18,19 +18,20 @@ sub register ($self, $app, $conf) {
       my $req = $c->req;
 
       Sentry::Hub->get_current_hub()->with_scope(sub ($scope) {
+        my %cookies = map { ($_->name, $_->value) } ($req->cookies // [])->@*;
         my $transaction = Sentry::SDK->start_transaction(
           {
-            name => $c->match->endpoint->pattern->unparsed || '/',
-            op   => 'http.server',
-          },
-          {
+            name    => $c->match->endpoint->pattern->unparsed || '/',
+            op      => 'http.server',
             request => {
-              url     => $req->url->to_string,
-              method  => $req->method,
-              query   => $req->url->query,
-              headers => $req->headers,
-            }
-          }
+              url          => $req->url->to_abs->to_string,
+              cookies      => \%cookies,
+              method       => $req->method,
+              query_string => $req->url->query->to_hash,
+              headers      => $req->headers->to_hash,
+              env          => \%ENV,
+            },
+          },
         );
 
         Sentry::SDK->configure_scope(sub ($scope) {
@@ -39,12 +40,12 @@ sub register ($self, $app, $conf) {
 
         try {
           $next->();
-
         } catch {
           Sentry::SDK->capture_exception($_);
           $c->reply->exception($_)
         } finally {
-          $transaction->set_http_status($c->res->code);
+          my $status = $c->res->code;
+          $transaction->set_http_status() if $status;
           $transaction->finish();
         }
 
